==> libfwbuilder_2.0.3.orig.tar.gz: libfwbuilder-2.0.3/src/fwbuilder/ICMPService.cpp <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: ICMPService.cpp,v 1.2 2004/09/08 05:34:50 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include <assert.h>

#include <fwbuilder/libfwbuilder-config.h>

#include <fwbuilder/ICMPService.h>
#include <fwbuilder/XMLTools.h>

using namespace libfwbuilder;
using namespace std;

const char *ICMPService::TYPENAME={"ICMPService"};

ICMPService::ICMPService() 
{
    setStr("type", "-1");
    setStr("code", "-1");
}

ICMPService::ICMPService(const FWObject *root) : Service(root) 
{
    setStr("type", "-1");
    setStr("code", "-1");
}

ICMPService::~ICMPService() {}

string ICMPService::getProtocolName()    {    return "icmp";}
int    ICMPService::getProtocolNumber()  {    return 1;     }

void ICMPService::fromXML(xmlNodePtr root) throw(FWException)
{
    FWObject::fromXML(root);

    const char *n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("type")));
    assert(n!=NULL);
    setStr("type", n);
    FREEXMLBUFF(n);

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("code")));
    if(n!=NULL)
    {
        setStr("code", n);
        FREEXMLBUFF(n);
    }
}

==> libfwbuilder_2.1.19.orig.tar.gz: libfwbuilder-2.1.19/src/fwbuilder/ICMPService.cpp <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: ICMPService.cpp,v 1.3 2006/09/10 22:40:37 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include <assert.h>

#include <fwbuilder/libfwbuilder-config.h>

#include <fwbuilder/ICMPService.h>
#include <fwbuilder/XMLTools.h>

using namespace libfwbuilder;
using namespace std;

const char *ICMPService::TYPENAME={"ICMPService"};

ICMPService::ICMPService() 
{
    setStr("type", "-1");
    setStr("code", "-1");
}

ICMPService::ICMPService(const FWObject *root,bool prepopulate) : Service(root,prepopulate) 
{
    setStr("type", "-1");
    setStr("code", "-1");
}

ICMPService::~ICMPService() {}

string ICMPService::getProtocolName()    {    return "icmp";}
int    ICMPService::getProtocolNumber()  {    return 1;     }

void ICMPService::fromXML(xmlNodePtr root) throw(FWException)
{
    FWObject::fromXML(root);

    const char *n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("type")));
    assert(n!=NULL);
    setStr("type", n);
    FREEXMLBUFF(n);

    n=FROMXMLCAST(xmlGetProp(root,TOXMLCAST("code")));
    if(n!=NULL)
    {
        setStr("code", n);
        FREEXMLBUFF(n);
    }
}
